@@ -43,22 +43,23 @@
 #include <glib/gstdio.h>
 #include <glib/gi18n-lib.h>
 
+#include "brasero-session.h"
+#include "brasero-session-helper.h"
 
 #include "burn-basics.h"
 #include "burn-debug.h"
 #include "libbrasero-marshal.h"
 #include "burn-image-format.h"
+#include "brasero-track-type-private.h"
 
 #include "brasero-medium.h"
 #include "brasero-drive.h"
 #include "brasero-medium-monitor.h"
 
 #include "brasero-tags.h"
-#include "brasero-session.h"
 #include "brasero-track.h"
 #include "brasero-track-disc.h"
 
-
 G_DEFINE_TYPE (BraseroBurnSession, brasero_burn_session, G_TYPE_OBJECT);
 #define BRASERO_BURN_SESSION_PRIVATE(o)  (G_TYPE_INSTANCE_GET_PRIVATE ((o), BRASERO_TYPE_BURN_SESSION, BraseroBurnSessionPrivate))
 
@@ -111,6 +112,8 @@ struct _BraseroBurnSessionPrivate {
 
 	GSList *tracks;
 	GSList *pile_tracks;
+
+	guint strict_checks:1;
 };
 typedef struct _BraseroBurnSessionPrivate BraseroBurnSessionPrivate;
 
@@ -245,12 +248,63 @@ brasero_burn_session_free_tracks (BraseroBurnSession *self)
 	}
 }
 
+/**
+ * brasero_burn_session_set_strict_support:
+ * @session: a #BraseroBurnSession.
+ * @flags: a #BraseroSessionCheckFlags
+ *
+ * For the following functions:
+ * brasero_burn_session_supported ()
+ * brasero_burn_session_input_supported ()
+ * brasero_burn_session_output_supported ()
+ * brasero_burn_session_can_blank ()
+ * this function sets whether these functions will
+ * ignore the plugins with errors (%TRUE).
+ */
+
+void
+brasero_burn_session_set_strict_support (BraseroBurnSession *session,
+                                         gboolean strict_checks)
+{
+	BraseroBurnSessionPrivate *priv;
+
+	g_return_if_fail (BRASERO_IS_BURN_SESSION (session));
+
+	priv = BRASERO_BURN_SESSION_PRIVATE (session);
+	priv->strict_checks = strict_checks;
+}
+
+/**
+ * brasero_burn_session_get_strict_support:
+ * @session: a #BraseroBurnSession.
+ *
+ * For the following functions:
+ * brasero_burn_session_can_burn ()
+ * brasero_burn_session_input_supported ()
+ * brasero_burn_session_output_supported ()
+ * brasero_burn_session_can_blank ()
+ * this function gets whether the checks will 
+ * ignore the plugins with errors (return %TRUE).
+ *
+ * Returns:  #gboolean
+ */
+
+gboolean
+brasero_burn_session_get_strict_support (BraseroBurnSession *session)
+{
+	BraseroBurnSessionPrivate *priv;
+
+	g_return_val_if_fail (BRASERO_IS_BURN_SESSION (session), FALSE);
+
+	priv = BRASERO_BURN_SESSION_PRIVATE (session);
+	return priv->strict_checks;
+}
 
 /**
  * brasero_burn_session_add_track:
- * @session: a #BraseroBurnSession
- * @new_track: a #BraseroTrack or NULL
- * @sibling: a #BraseroTrack or NULL
+ * @session: a #BraseroBurnSession.
+ * @new_track: (allow-none): a #BraseroTrack or NULL.
+ * @sibling: (allow-none): a #BraseroTrack or NULL.
  *
  * Inserts a new track after @sibling or appended if @sibling is NULL. If @track is NULL then all tracks
  * already in @session will be removed.
@@ -329,9 +383,9 @@ brasero_burn_session_add_track (BraseroBurnSession *self,
 
 /**
  * brasero_burn_session_move_track:
- * @session: a #BraseroBurnSession
- * @track: a #BraseroTrack
- * @sibling: a #BraseroTrack or NULL
+ * @session: a #BraseroBurnSession.
+ * @track: a #BraseroTrack.
+ * @sibling: (allow-none): a #BraseroTrack or NULL.
  *
  * Moves @track after @sibling; if @sibling is NULL then it is appended.
  *
@@ -423,7 +477,8 @@ brasero_burn_session_remove_track (BraseroBurnSession *session,
  *
  * Returns the list of #BraseroTrack added to @session.
  *
- * Return value: a #GSList or #BraseroTrack object. Do not unref the objects in the list nor destroy the list.
+ * Return value: (element-type BraseroBurn.Track) (transfer none): a #GSList or #BraseroTrack object. Do not unref the objects in the list nor destroy the list.
+ *
  **/
 
 GSList *
@@ -480,14 +535,14 @@ brasero_burn_session_get_status (BraseroBurnSession *session,
 		if (result == BRASERO_BURN_NOT_READY)
 			not_ready ++;
 		else if (result != BRASERO_BURN_OK) {
-			brasero_status_free (track_status);
+			g_object_unref (track_status);
 			return brasero_track_get_status (track, status);
 		}
 
 		if (brasero_status_get_progress (track_status) != -1.0)
 			done += brasero_status_get_progress (track_status);
 	}
-	brasero_status_free (track_status);
+	g_object_unref (track_status);
 
 	if (not_ready > 0) {
 		if (status) {
@@ -581,20 +636,29 @@ BraseroBurnResult
 brasero_burn_session_get_input_type (BraseroBurnSession *self,
 				     BraseroTrackType *type)
 {
-	BraseroTrack *track;
+	GSList *iter;
+	BraseroStreamFormat format;
 	BraseroBurnSessionPrivate *priv;
 
 	g_return_val_if_fail (BRASERO_IS_BURN_SESSION (self), BRASERO_BURN_ERR);
 
 	priv = BRASERO_BURN_SESSION_PRIVATE (self);
 
-	if (!priv->tracks)
-		return BRASERO_BURN_OK;
-
 	/* there can be many tracks (in case of audio) but they must be
-	 * all of the same kind for the moment */
-	track = priv->tracks->data;
-	brasero_track_get_track_type (track, type);
+	 * all of the same kind for the moment. Yet their subtypes may
+	 * be different. */
+	format = BRASERO_AUDIO_FORMAT_NONE;
+	for (iter = priv->tracks; iter; iter = iter->next) {
+		BraseroTrack *track;
+
+		track = iter->data;
+		brasero_track_get_track_type (track, type);
+		if (brasero_track_type_get_has_stream (type))
+			format |= brasero_track_type_get_stream_format (type);
+	}
+
+	if (brasero_track_type_get_has_stream (type))
+		brasero_track_type_set_image_format (type, format);
 
 	return BRASERO_BURN_OK;
 }
@@ -695,7 +759,7 @@ brasero_burn_session_set_burner (BraseroBurnSession *self,
  *
  * Returns the #BraseroDrive that should be used to burn the session contents.
  *
- * Return value: a #BraseroDrive or NULL. Do not unref after use.
+ * Return value: (transfer none) (allow-none): a #BraseroDrive or NULL. Do not unref after use.
  **/
 
 BraseroDrive *
@@ -776,10 +840,44 @@ brasero_burn_session_get_rate (BraseroBurnSession *self)
 }
 
 /**
- * brasero_burn_session_get_output:
+ * brasero_burn_session_get_output_type:
  * @session: a #BraseroBurnSession
- * @image: a #gchar or NULL
- * @toc: a #gchar or NULL
+ * @output: a #BraseroTrackType or NULL
+ *
+ * This function returns the type of output set for the session.
+ *
+ * Return value: a #BraseroBurnResult.
+ * BRASERO_BURN_OK if it was successful; BRASERO_BURN_NOT_READY if no setting has been set; BRASERO_BURN_ERR otherwise.
+ **/
+BraseroBurnResult
+brasero_burn_session_get_output_type (BraseroBurnSession *self,
+                                      BraseroTrackType *output)
+{
+	BraseroBurnSessionPrivate *priv;
+
+	g_return_val_if_fail (BRASERO_IS_BURN_SESSION (self), BRASERO_BURN_ERR);
+
+	priv = BRASERO_BURN_SESSION_PRIVATE (self);
+	if (!priv->settings->burner)
+		return BRASERO_BURN_NOT_READY;
+
+	if (brasero_drive_is_fake (priv->settings->burner)) {
+		brasero_track_type_set_has_image (output);
+		brasero_track_type_set_image_format (output, brasero_burn_session_get_output_format (self));
+	}
+	else {
+		brasero_track_type_set_has_medium (output);
+		brasero_track_type_set_medium_type (output, brasero_medium_get_status (brasero_drive_get_medium (priv->settings->burner)));
+	}
+
+	return BRASERO_BURN_OK;
+}
+
+/**
+ * brasero_burn_session_get_output:
+ * @session: a #BraseroBurnSession.
+ * @image: (allow-none) (out): a #gchar to store the image path or NULL.
+ * @toc: (allow-none) (out): a #gchar to store the toc path or NULL.
  *
  * When the contents of @session should be written to a
  * file then this function returns the image path (and if
@@ -939,6 +1037,23 @@ brasero_burn_session_set_image_output_real (BraseroBurnSession *self,
 	priv->settings->format = format;
 }
 
+static void
+brasero_burn_session_set_fake_drive (BraseroBurnSession *self)
+{
+	BraseroMediumMonitor *monitor;
+	BraseroDrive *drive;
+	GSList *list;
+
+	/* NOTE: changing/changed signals are handled in
+	 * set_burner (). */
+	monitor = brasero_medium_monitor_get_default ();
+	list = brasero_medium_monitor_get_media (monitor, BRASERO_MEDIA_TYPE_FILE);
+	drive = brasero_medium_get_drive (list->data);
+	brasero_burn_session_set_burner (self, drive);
+	g_object_unref (monitor);
+	g_slist_free (list);
+}
+
 static BraseroBurnResult
 brasero_burn_session_set_output_image_real (BraseroBurnSession *self,
 					    BraseroImageFormat format,
@@ -952,45 +1067,20 @@ brasero_burn_session_set_output_image_real (BraseroBurnSession *self,
 	if (priv->settings->format == format
 	&&  BRASERO_STR_EQUAL (image, priv->settings->image)
 	&&  BRASERO_STR_EQUAL (toc, priv->settings->toc)) {
-		if (!BRASERO_BURN_SESSION_WRITE_TO_FILE (priv)) {
-			BraseroMediumMonitor *monitor;
-			BraseroDrive *drive;
-			GSList *list;
-
-			/* NOTE: changing/changed signals are handled in
-			 * set_burner (). */
-			monitor = brasero_medium_monitor_get_default ();
-			list = brasero_medium_monitor_get_media (monitor, BRASERO_MEDIA_TYPE_FILE);
-			drive = brasero_medium_get_drive (list->data);
-			brasero_burn_session_set_burner (self, drive);
-			g_object_unref (monitor);
-			g_slist_free (list);
-		}
+		if (!BRASERO_BURN_SESSION_WRITE_TO_FILE (priv))
+			brasero_burn_session_set_fake_drive (self);
 
 		return BRASERO_BURN_OK;
 	}
 
-	if (!BRASERO_BURN_SESSION_WRITE_TO_FILE (priv)) {
-		BraseroMediumMonitor *monitor;
-		BraseroDrive *drive;
-		GSList *list;
-
-		brasero_burn_session_set_image_output_real (self, format, image, toc);
-
-		monitor = brasero_medium_monitor_get_default ();
-		list = brasero_medium_monitor_get_media (monitor, BRASERO_MEDIA_TYPE_FILE);
-		drive = brasero_medium_get_drive (list->data);
-		brasero_burn_session_set_burner (self, drive);
-		g_object_unref (monitor);
-		g_slist_free (list);
-	}
-	else {
-		brasero_burn_session_set_image_output_real (self, format, image, toc);
+	brasero_burn_session_set_image_output_real (self, format, image, toc);
+	if (BRASERO_BURN_SESSION_WRITE_TO_FILE (priv))
 		g_signal_emit (self,
 			       brasero_burn_session_signals [OUTPUT_CHANGED_SIGNAL],
 			       0,
 			       brasero_drive_get_medium (priv->settings->burner));
-	}
+	else
+		brasero_burn_session_set_fake_drive (self);
 
 	return BRASERO_BURN_OK;
 }
@@ -1007,6 +1097,8 @@ brasero_burn_session_set_output_image_real (BraseroBurnSession *self,
  * NOTE: after a call to this function the #BraseroDrive for
  * @session will be the fake #BraseroDrive.
  *
+ * Since 2.29.0
+ *
  * Return value: a #BraseroBurnResult. BRASERO_BURN_OK if it was successfully set;
  * BRASERO_BURN_ERR otherwise.
  **/
@@ -1037,10 +1129,10 @@ brasero_burn_session_set_image_output_format (BraseroBurnSession *self,
 
 /**
  * brasero_burn_session_set_image_output_full:
- * @session: a #BraseroBurnSession
- * @format: a #BraseroImageFormat
- * @image: a #gchar or NULL
- * @toc: a #gchar or NULL
+ * @session: a #BraseroBurnSession.
+ * @format: a #BraseroImageFormat.
+ * @image: (allow-none): a #gchar or NULL.
+ * @toc: (allow-none): a #gchar or NULL.
  *
  * When the contents of @session should be written to a
  * file, this function sets the different parameters of this
@@ -1471,7 +1563,7 @@ brasero_burn_session_get_flags (BraseroBurnSession *self)
 /**
  * brasero_burn_session_set_label:
  * @session: a #BraseroBurnSession
- * @label: a #gchar
+ * @label: (allow-none): a #gchar or %NULL
  *
  * Sets the label for @session.
  *
@@ -1631,6 +1723,8 @@ brasero_burn_session_tag_add (BraseroBurnSession *self,
  * for video discs, ...
  * See brasero-tags.h for a list of knowns tags.
  *
+ * Since 2.29.0
+ *
  * Return value: a #BraseroBurnResult.
  * BRASERO_BURN_OK if it was successful,
  * BRASERO_BURN_ERR otherwise.
@@ -1705,6 +1799,8 @@ brasero_burn_session_tag_lookup (BraseroBurnSession *self,
  * Retrieves an int value associated with @session through
  * brasero_session_tag_add () and returns it.
  *
+ * Since 2.29.0
+ *
  * Return value: a #gint.
  **/
 
