@@ -40,8 +40,9 @@ fy
 #include "brasero-plugin-manager-ui.h"
 
 #include "brasero-plugin.h"
+#include "brasero-plugin-private.h"
 #include "brasero-plugin-information.h"
-#include "burn-plugin-manager.h"
+#include "brasero-burn-lib.h"
 #include "brasero-plugin-option.h"
 
 typedef enum {
@@ -204,6 +205,7 @@ plugin_manager_ui_view_info_cell_cb (GtkTreeViewColumn *tree_column,
 				     gpointer           data)
 {
 	BraseroPlugin *plugin;
+	gchar *error_string;
 	gchar *text;
 	
 	g_return_if_fail (tree_model != NULL);
@@ -216,13 +218,16 @@ plugin_manager_ui_view_info_cell_cb (GtkTreeViewColumn *tree_column,
 	if (!plugin)
 		return;
 
-	if (brasero_plugin_get_error (plugin))
+	error_string = brasero_plugin_get_error_string (plugin);
+	if (error_string) {
 		text = g_markup_printf_escaped ("<b>%s</b>\n%s\n<i>%s</i>",
 						/* Use the translated name of 
 						 * the plugin. */
 						_(brasero_plugin_get_name (plugin)),
 						brasero_plugin_get_description (plugin),
-						brasero_plugin_get_error (plugin));
+						error_string);
+		g_free (error_string);
+	}
 	else
 		text = g_markup_printf_escaped ("<b>%s</b>\n%s",
 						/* Use the translated name of 
@@ -232,7 +237,7 @@ plugin_manager_ui_view_info_cell_cb (GtkTreeViewColumn *tree_column,
 
 	g_object_set (G_OBJECT (cell),
 		      "markup", text,
-		      "sensitive", brasero_plugin_get_gtype (plugin) != G_TYPE_NONE,
+		      "sensitive", brasero_plugin_get_gtype (plugin) != G_TYPE_NONE && !brasero_plugin_get_compulsory (plugin),
 		      NULL);
 
 	g_free (text);
@@ -245,12 +250,16 @@ plugin_manager_ui_view_icon_cell_cb (GtkTreeViewColumn *tree_column,
 				     GtkTreeIter       *iter,
 				     gpointer           data)
 {
+	BraseroPlugin *plugin;
 	
 	g_return_if_fail (tree_model != NULL);
 	g_return_if_fail (tree_column != NULL);
 
+	gtk_tree_model_get (tree_model, iter, PLUGIN_COLUMN, &plugin, -1);
+
 	g_object_set (G_OBJECT (cell),
 		      "visible", FALSE,
+		      "sensitive", brasero_plugin_get_gtype (plugin) != G_TYPE_NONE && !brasero_plugin_get_compulsory (plugin),
 		      NULL);
 	return;
 /*
@@ -293,7 +302,6 @@ active_toggled_cb (GtkCellRendererToggle *cell,
 	g_return_if_fail (model != NULL);
 
 	gtk_tree_model_get_iter (model, &iter, path);
-
 	if (&iter != NULL)
 		plugin_manager_ui_toggle_active (&iter, model);
 
@@ -358,14 +366,10 @@ plugin_manager_ui_populate_lists (BraseroPluginManagerUI *pm)
 	for (; plugins; plugins = plugins->next) {
 		plugin = plugins->data;
 
-		if (brasero_plugin_get_gtype (plugin) == G_TYPE_NONE
-		||  brasero_plugin_get_compulsory (plugin))
-			continue;
-
 		gtk_list_store_append (model, &iter);
 		gtk_list_store_set (model, &iter,
-				    ACTIVE_COLUMN, brasero_plugin_get_active (plugin),
-				    AVAILABLE_COLUMN, brasero_plugin_get_gtype (plugin) != G_TYPE_NONE,
+				    ACTIVE_COLUMN, brasero_plugin_get_active (plugin, 0),
+				    AVAILABLE_COLUMN, brasero_plugin_get_gtype (plugin) != G_TYPE_NONE && !brasero_plugin_get_compulsory (plugin),
 				    PLUGIN_COLUMN, plugin,
 				    -1);
 	}
@@ -408,13 +412,17 @@ plugin_manager_ui_set_active (GtkTreeIter  *iter,
 
 	g_return_val_if_fail (plugin != NULL, FALSE);
 
+	if (brasero_plugin_get_gtype (plugin) == G_TYPE_NONE
+	||  brasero_plugin_get_compulsory (plugin))
+		return FALSE;
+
 	brasero_plugin_set_active (plugin, active);
  
 	/* set new value */
 	gtk_list_store_set (GTK_LIST_STORE (model), 
 			    iter, 
-			    ACTIVE_COLUMN, brasero_plugin_get_active (plugin),
-			    AVAILABLE_COLUMN, brasero_plugin_get_gtype (plugin) != G_TYPE_NONE,
+			    ACTIVE_COLUMN, brasero_plugin_get_active (plugin, 0),
+			    AVAILABLE_COLUMN, brasero_plugin_get_gtype (plugin) != G_TYPE_NONE && !brasero_plugin_get_compulsory (plugin),
 			    -1);
 
 	/* search if this plugin appears under other categories
@@ -439,7 +447,7 @@ plugin_manager_ui_set_active (GtkTreeIter  *iter,
 			if (plugin == tmp_plugin) {
 				gtk_list_store_set (GTK_LIST_STORE (model), &child, 
 						    ACTIVE_COLUMN, active,
-						    AVAILABLE_COLUMN, brasero_plugin_get_gtype (plugin) != G_TYPE_NONE,
+						    AVAILABLE_COLUMN, brasero_plugin_get_gtype (plugin) != G_TYPE_NONE && !brasero_plugin_get_compulsory (plugin),
 						    -1);
 				break;
 			}
@@ -461,7 +469,8 @@ plugin_manager_ui_toggle_active (GtkTreeIter  *iter,
 
 	active ^= 1;
 
-	plugin_manager_ui_set_active (iter, model, active);
+	if (!plugin_manager_ui_set_active (iter, model, active))
+		return;
 }
 
 static void
@@ -600,9 +609,9 @@ create_tree_popup_menu (BraseroPluginManagerUI *pm)
 
 	item = gtk_check_menu_item_new_with_mnemonic (_("A_ctivate"));
 	gtk_widget_set_sensitive (item,
-				  brasero_plugin_get_gtype (plugin) != G_TYPE_NONE);	
+				  brasero_plugin_get_gtype (plugin) != G_TYPE_NONE && !brasero_plugin_get_compulsory (plugin));	
 	gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (item),
-					brasero_plugin_get_active (plugin));
+					brasero_plugin_get_active (plugin, 0));
 	g_signal_connect (item, "toggled",
 			  G_CALLBACK (enable_plugin_menu_cb), pm);
 	gtk_menu_shell_append (GTK_MENU_SHELL (menu), item);					
@@ -795,10 +804,20 @@ model_name_sort_func (GtkTreeModel *model,
 		      gpointer      user_data)
 {
 	BraseroPlugin *plugin1, *plugin2;
+	gboolean active1, active2;
 	
 	gtk_tree_model_get (model, iter1, PLUGIN_COLUMN, &plugin1, -1);
 	gtk_tree_model_get (model, iter2, PLUGIN_COLUMN, &plugin2, -1);
 
+	active1 = brasero_plugin_get_gtype (plugin1) != G_TYPE_NONE && !brasero_plugin_get_compulsory (plugin1);
+	active2 = brasero_plugin_get_gtype (plugin2) != G_TYPE_NONE && !brasero_plugin_get_compulsory (plugin2);
+
+	if (active1 && !active2)
+		return -1;
+
+	if (active2 && !active1)
+		return 1;
+
 	/* Use the translated name for the plugins */
 	return g_utf8_collate (_(brasero_plugin_get_name (plugin1)),
 			       _(brasero_plugin_get_name (plugin2)));
@@ -835,12 +854,18 @@ plugin_manager_ui_construct_tree (BraseroPluginManagerUI *pm)
 	cell = gtk_cell_renderer_pixbuf_new ();
 	gtk_tree_view_column_pack_start (column, cell, FALSE);
 	g_object_set (cell, "stock-size", GTK_ICON_SIZE_SMALL_TOOLBAR, NULL);
+	gtk_tree_view_column_add_attribute (column,
+	                                    cell,
+	                                    "sensitive", AVAILABLE_COLUMN);
 	gtk_tree_view_column_set_cell_data_func (column, cell,
 						 plugin_manager_ui_view_icon_cell_cb,
 						 pm, NULL);
 	
 	cell = gtk_cell_renderer_text_new ();
 	gtk_tree_view_column_pack_start (column, cell, TRUE);
+	gtk_tree_view_column_add_attribute (column,
+	                                    cell,
+	                                    "sensitive", AVAILABLE_COLUMN);
 	g_object_set (cell, "ellipsize", PANGO_ELLIPSIZE_END, NULL);
 	gtk_tree_view_column_set_cell_data_func (column, cell,
 						 plugin_manager_ui_view_info_cell_cb,
@@ -851,7 +876,6 @@ plugin_manager_ui_construct_tree (BraseroPluginManagerUI *pm)
 
 	/* Last column */
 	cell = gtk_cell_renderer_toggle_new ();
-	g_object_set (cell, "xpad", 6, NULL);
 	g_signal_connect (cell,
 			  "toggled",
 			  G_CALLBACK (active_toggled_cb),
@@ -866,6 +890,7 @@ plugin_manager_ui_construct_tree (BraseroPluginManagerUI *pm)
 	gtk_tree_view_column_set_title (column, PLUGIN_MANAGER_UI_ACTIVE_TITLE);
 	gtk_tree_view_column_set_expand (column, FALSE);
 	gtk_tree_view_append_column (GTK_TREE_VIEW (priv->tree), column);
+	g_object_set (cell, "xpad", 6, NULL);
 
 	/* Sort on the plugin names */
 	gtk_tree_sortable_set_default_sort_func (GTK_TREE_SORTABLE (model),
@@ -912,7 +937,6 @@ brasero_plugin_manager_ui_init (BraseroPluginManagerUI *pm)
 	GtkWidget *viewport;
 	GtkWidget *alignment;
 	GtkWidget *vbuttonbox;
-	BraseroPluginManager *manager;
 	BraseroPluginManagerUIPrivate *priv;
 
 	priv = BRASERO_PLUGIN_MANAGER_UI_GET_PRIVATE (pm);
@@ -977,8 +1001,7 @@ brasero_plugin_manager_ui_init (BraseroPluginManagerUI *pm)
 	plugin_manager_ui_construct_tree (pm);
 
 	/* get the list of available plugins (or installed) */
-	manager = brasero_plugin_manager_get_default ();
-	priv->plugins = brasero_plugin_manager_get_plugins_list (manager);
+	priv->plugins = brasero_burn_library_get_plugins_list ();
 
 	if (!priv->plugins){
 		gtk_widget_set_sensitive (priv->about_button, FALSE);
@@ -997,6 +1020,7 @@ brasero_plugin_manager_ui_finalize (GObject *object)
 	priv = BRASERO_PLUGIN_MANAGER_UI_GET_PRIVATE (pm);
 
 	if (priv->plugins) {
+		g_slist_foreach (priv->plugins, (GFunc) g_object_unref, NULL);
 		g_slist_free (priv->plugins);
 		priv->plugins = NULL;
 	}
