@@ -80,8 +80,8 @@ static ItemDescription items [] = {
 	"media-optical-data-new",
 	BRASERO_PROJECT_TYPE_DATA},
        {N_("_Video project"),
-	N_("Create a video DVD or a SVCD"),
-	N_("Create a video DVD or a SVCD that are readable on TV readers"),
+	N_("Create a video DVD or an SVCD"),
+	N_("Create a video DVD or an SVCD that are readable on TV readers"),
 	"media-optical-video-new",
 	BRASERO_PROJECT_TYPE_VIDEO},
        {N_("Disc _copy"),
@@ -304,7 +304,7 @@ brasero_project_type_chooser_build_recent (BraseroProjectTypeChooser *self,
 				  self);
 
 		gtk_widget_show (link);
-		gtk_widget_set_tooltip_text (link, _("Load the last project that was not burnt and not saved"));
+		gtk_widget_set_tooltip_text (link, _("Load the last project that was not burned and not saved"));
 		gtk_box_pack_start (GTK_BOX (self->priv->recent_box), link, FALSE, TRUE, 0);
 
 		gtk_size_group_add_widget (group, link);
