@@ -70,13 +70,13 @@ gint open_ncb;
 gint parent_window;
 
 static const GOptionEntry options [] = {
-	{ "project", 'p', 0, G_OPTION_ARG_STRING, &project_uri,
+	{ "project", 'p', 0, G_OPTION_ARG_FILENAME, &project_uri,
 	  N_("Open the specified project"),
 	  N_("PROJECT") },
 
 #ifdef BUILD_PLAYLIST
 
-	 { "playlist", 'l', 0, G_OPTION_ARG_STRING, &playlist_uri,
+	 { "playlist", 'l', 0, G_OPTION_ARG_FILENAME, &playlist_uri,
 	  N_("Open the specified playlist as an audio project"),
 	  N_("PLAYLIST") },
 
@@ -94,7 +94,7 @@ static const GOptionEntry options [] = {
 	  N_("Copy a disc"),
 	  N_("PATH TO DEVICE") },
 
-	{ "cover", 'j', 0, G_OPTION_ARG_STRING, &cover_project,
+	{ "cover", 'j', 0, G_OPTION_ARG_FILENAME, &cover_project,
 	  N_("Cover to use"),
 	  N_("PATH TO COVER") },
 
@@ -102,8 +102,8 @@ static const GOptionEntry options [] = {
 	  N_("Open a video project adding the URIs given on the command line"),
 	  NULL },
 
-	{ "image", 'i', 0, G_OPTION_ARG_STRING, &iso_uri,
-	 N_("Uri of an image file to be burnt (autodetected)"),
+	{ "image", 'i', 0, G_OPTION_ARG_FILENAME, &iso_uri,
+	 N_("URI of an image file to burn (autodetected)"),
           N_("PATH TO PLAYLIST") },
 
     	{ "empty", 'e', 0, G_OPTION_ARG_NONE, &empty_project,
@@ -122,8 +122,8 @@ static const GOptionEntry options [] = {
 	  N_("Burn the contents of burn:// URI"),
 	  NULL },
 
-	{ "burn-and-remove-project", 'r', 0, G_OPTION_ARG_STRING, &burn_project_uri,
-	  N_("Burn the specified project and REMOVE it.\nThis option is mainly useful for integration use with other applications."),
+	{ "burn-and-remove-project", 'r', 0, G_OPTION_ARG_FILENAME, &burn_project_uri,
+	  N_("Burn the specified project and remove it.\nThis option is mainly useful for integration with other applications."),
 	  N_("PATH") },
 
 	{ "transient-for", 'x', 0, G_OPTION_ARG_INT, &parent_window,
@@ -199,9 +199,9 @@ brasero_handle_burn_uri (BraseroApp *app,
 		gchar *string;
 
 		if (error)
-			string = g_strdup_printf (_("An internal error occured (%s)"), error->message);
+			string = g_strdup_printf (_("An internal error occurred (%s)"), error->message);
 		else
-			string = g_strdup (_("An internal error occured"));
+			string = g_strdup (_("An internal error occurred"));
 
 		brasero_app_alert (app,
 				   _("Error while loading the project"),
@@ -225,9 +225,9 @@ brasero_handle_burn_uri (BraseroApp *app,
 		gchar *string;
 
 		if (error)
-			string = g_strdup_printf (_("An internal error occured (%s)"), error->message);
+			string = g_strdup_printf (_("An internal error occurred (%s)"), error->message);
 		else
-			string = g_strdup (_("An internal error occured"));
+			string = g_strdup (_("An internal error occurred"));
 
 		brasero_app_alert (app,
 				   _("Error while loading the project"),
@@ -260,30 +260,6 @@ brasero_handle_burn_uri (BraseroApp *app,
 	return;
 }
 
-static gboolean
-brasero_app_open_project (BraseroApp *app,
-			  const gchar *path,
-			  gboolean playlist,
-			  gboolean burn)
-{
-	BraseroProjectType type;
-	GtkWidget *manager;
-	GFile *file;
-	gchar *uri;
-
-	brasero_app_create_mainwin (app);
-
-	file = g_file_new_for_commandline_arg (path);
-	uri = g_file_get_uri (file);
-	g_object_unref (file);
-
-	manager = brasero_app_get_project_manager (app);
-	type = brasero_project_manager_open_project (BRASERO_PROJECT_MANAGER (manager), uri, playlist, burn);
-	g_free (uri);
-
-	return (type != BRASERO_PROJECT_TYPE_INVALID);
-}
-
 static void
 brasero_app_parse_options (BraseroApp *app)
 {
@@ -297,6 +273,7 @@ brasero_app_parse_options (BraseroApp *app)
 	    	brasero_app_create_mainwin (app);
 		manager = brasero_app_get_project_manager (app);
 		brasero_project_manager_empty (BRASERO_PROJECT_MANAGER (manager));
+		brasero_app_run_mainwin (app);
 		return;
 	}
 
@@ -334,10 +311,10 @@ brasero_app_parse_options (BraseroApp *app)
 		brasero_project_manager_empty (BRASERO_PROJECT_MANAGER (manager));
 	}
 	else if (project_uri) {
-		brasero_app_open_project (app, project_uri, FALSE, FALSE);
+		brasero_app_open_project (app, project_uri, FALSE, TRUE, FALSE);
 	}
 	else if (burn_project_uri) {
-		brasero_app_open_project (app, burn_project_uri, FALSE, TRUE);
+		brasero_app_open_project (app, burn_project_uri, FALSE, TRUE, TRUE);
 
 		if (g_remove (burn_project_uri) != 0) {
 			gchar *path;
@@ -352,7 +329,7 @@ brasero_app_parse_options (BraseroApp *app)
 #ifdef BUILD_PLAYLIST
 
 	else if (playlist_uri) {
-		brasero_app_open_project (app, playlist_uri, TRUE, FALSE);
+		brasero_app_open_project (app, playlist_uri, TRUE, TRUE, FALSE);
 	}
 
 #endif
@@ -430,21 +407,13 @@ brasero_app_parse_options (BraseroApp *app)
 		return;
 	}
 	else if (files) {
+		if (g_strv_length (files) == 1
+		&&  brasero_app_open_uri (app, files [0], FALSE))
+			return;
+
 		brasero_app_create_mainwin (app);
 		manager = brasero_app_get_project_manager (app);
-
-		if (g_strv_length (files) == 1) {
-			BraseroProjectType type;
-
-			type = brasero_project_manager_open_uri (BRASERO_PROJECT_MANAGER (manager), files [0]);
-
-			/* Fallback if it hasn't got a suitable URI */
-			if (type == BRASERO_PROJECT_TYPE_INVALID) {
-				BRASERO_PROJECT_OPEN_LIST (manager, brasero_project_manager_data, files, FALSE);
-			}
-		}
-		else
-			BRASERO_PROJECT_OPEN_LIST (manager, brasero_project_manager_data, files, FALSE);
+		BRASERO_PROJECT_OPEN_LIST (manager, brasero_project_manager_data, files, FALSE);
 	}
 	else {
 		brasero_app_create_mainwin (app);
@@ -481,7 +450,7 @@ main (int argc, char **argv)
 	g_thread_init (NULL);
 	g_type_init ();
 
-	context = g_option_context_new (_("[URI] [URI] ..."));
+	context = g_option_context_new (_("[URI] [URI] …"));
 	g_option_context_add_main_entries (context,
 					   options,
 					   GETTEXT_PACKAGE);
@@ -493,7 +462,7 @@ main (int argc, char **argv)
 	g_option_context_add_group (context, brasero_burn_library_get_option_group ());
 	g_option_context_add_group (context, gst_init_get_option_group ());
 	if (g_option_context_parse (context, &argc, &argv, NULL) == FALSE) {
-		g_print (_("Please type %s --help to see all available options\n"), argv [0]);
+		g_print (_("Please type \"%s --help\" to see all available options\n"), argv [0]);
 		g_option_context_free (context);
 		exit (1);
 	}
@@ -518,6 +487,8 @@ main (int argc, char **argv)
 		return 1;
 
 	brasero_app_parse_options (current_app);
+
+	g_object_unref (current_app);
 	current_app = NULL;
 
 	brasero_burn_library_stop ();
